@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.005000';
+$MetaCPAN::Client::VERSION = '2.006000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -34,8 +34,9 @@ sub BUILDARGS {
     my ( $class, %args ) = @_;
 
     $args{'request'} ||= MetaCPAN::Client::Request->new(
-        ( ua      => $args{ua}      )x!! $args{ua},
-        ( domain  => $args{domain}  )x!! $args{domain},
+        ( ua     => $args{ua}     )x!! $args{ua},
+        ( domain => $args{domain} )x!! $args{domain},
+        ( debug  => $args{debug}  )x!! $args{debug},
     );
 
     return \%args;
@@ -371,7 +372,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.005000
+version 2.006000
 
 =head1 SYNOPSIS
 
@@ -424,6 +425,10 @@ L<MetaCPAN::Client::Request>.
 
 If given, will be used to alter the API domain.
 
+=head2 debug
+
+If given, errors will include some low-level detailed message.
+
 =head1 METHODS
 
 =head2 author
@@ -563,6 +568,12 @@ See SEARCH PARAMS.
 
    my $all_releases = $mcpan->all('releases', { fields => [...] })
 
+=head3 _source
+
+See SEARCH PARAMS.
+
+   my $all_releases = $mcpan->all('releases', { _source => [...] })
+
 =head3 es_filter
 
 Pass a raw ElasticSearch filter structure to reduce the number
@@ -590,6 +601,22 @@ can be passed as a csv list or an array ref.
     my $module = $mcpan->module('Moose', { fields => "version,author" });
     my $module = $mcpan->module('Moose', { fields => [qw/version author/] });
 
+=head2 _source
+
+Note: this param and its description are a bit too ElasticSearch specific.
+just like 'es_filter' - use only if you know what you're dealing with.
+
+Some fields are not indexed in ElasticSearch but stored as part of
+the entire document.
+
+These fields can still be read, but without the internal ElasticSearch
+optimizations and the server will interally read the whole document.
+
+Why do we even need those? because we don't index everything and some things
+we can't to begin with (like non-leaf fields that hold a structure)
+
+    my $module = $mcpan->all('releases', { _source => "stat" });
+
 =head1 SEARCH SPEC
 
 The hash-based search spec is common to many searches. It is quite
