@@ -2,15 +2,15 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '2.005000';
+$MetaCPAN::Client::Request::VERSION = '2.006000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
 use HTTP::Tiny;
-use Ref::Util qw< is_arrayref is_hashref >;
+use Ref::Util qw< is_arrayref is_hashref is_ref >;
 
 use MetaCPAN::Client::Scroll;
-use MetaCPAN::Client::Types qw< HashRef >;
+use MetaCPAN::Client::Types qw< HashRef Int >;
 
 has _clientinfo => (
     is      => 'ro',
@@ -62,6 +62,12 @@ has _is_agg => (
     writer  => '_set_is_agg'
 );
 
+has debug => (
+    is      => 'ro',
+    isa     => Int,
+    default => 0,
+);
+
 sub BUILDARGS {
     my ( $self, %args ) = @_;
     $args{domain} and $args{base_url} = $args{domain};
@@ -132,6 +138,7 @@ sub ssearch {
         base_url => $self->base_url,
         type     => $type,
         body     => $self->_build_body($args, $params),
+        debug    => $self->debug,
     );
 
     return $scroller;
@@ -181,7 +188,8 @@ sub _build_body {
 
     return +{
         query => $query,
-        _read_filters($params),
+        $self->_read_filters($params),
+        $self->_read_fields($params),
         $self->_read_aggregations($params)
     };
 }
@@ -192,6 +200,30 @@ my %key2es = (
     not    => 'must_not',
 );
 
+sub _read_fields {
+    my $self   = shift;
+    my $params = shift;
+
+    my $fields  = delete $params->{fields};
+    my $_source = delete $params->{_source};
+
+    my @ret;
+
+    if ( $fields ) {
+        is_arrayref($fields) or
+            croak "fields must be an arrayref";
+        push @ret => ( fields => $fields );
+    }
+
+    if ( $_source ) {
+        is_arrayref($_source) or !is_ref($_source) or
+            croak "_source must be an arrayref or a string";
+        push @ret => ( _source => $_source );
+    }
+
+    return @ret;
+}
+
 sub _read_aggregations {
     my $self   = shift;
     my $params = shift;
@@ -204,6 +236,7 @@ sub _read_aggregations {
 }
 
 sub _read_filters {
+    my $self   = shift;
     my $params = shift;
 
     my $filter = delete $params->{es_filter};
@@ -270,7 +303,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 2.005000
+version 2.006000
 
 =head1 ATTRIBUTES
 
@@ -330,6 +363,10 @@ Arguments sent to the user agent.
 
 Default: user agent string: B<MetaCPAN::Client/$version>.
 
+=head2 debug
+
+debug-mode for more detailed error messages.
+
 =head1 METHODS
 
 =head2 BUILDARGS
