@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Scroll;
 # ABSTRACT: A MetaCPAN::Client scroller
-$MetaCPAN::Client::Scroll::VERSION = '2.005000';
+$MetaCPAN::Client::Scroll::VERSION = '2.006000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_hashref >;
@@ -96,8 +96,11 @@ sub BUILDARGS {
         { content => encode_json $body }
     );
 
-    croak "failed to create a scrolled search"
-        unless $res->{status} == 200;
+    if ( $res->{status} != 200 ) {
+        my $msg = "failed to create a scrolled search";
+        $args{debug} and $msg .= "\n(" . $res->{content} . ")";
+        croak $msg;
+    }
 
     my $content = decode_json $res->{content};
 
@@ -174,7 +177,7 @@ MetaCPAN::Client::Scroll - A MetaCPAN::Client scroller
 
 =head1 VERSION
 
-version 2.005000
+version 2.006000
 
 =head1 METHODS
 
